<TS language="fa" version="2.0">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>ایجاد نشانی جدید</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;جدید</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>کپی نشانی انتخاب شده کنونی به حافظه‌ی سیستم</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;کپی</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>حذف نشانی انتخاب‌شده کنونی از لیست</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;حذف</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>کپی و برچسب‌&amp;گذاری</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;ویرایش</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>برچسب</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>آدرس</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(بدون برچسب)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>پنجرهٔ گذرواژه</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>گذرواژه را وارد کنید</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>گذرواژهٔ جدید</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>تکرار گذرواژهٔ جدید</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>رمزنگاری کیف پول</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>باز کردن قفل کیف پول</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>تأیید رمزنگاری کیف پول</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>آیا مطمئن هستید که می‌خواهید کیف پول خود را رمزنگاری کنید؟</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>کیف پول رمزنگاری شد</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>رمزنگاری کیف پول با شکست مواجه شد</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>رمزنگاری کیف پول بنا به یک خطای داخلی با شکست مواجه شد. کیف پول شما رمزنگاری نشد.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>بازگشایی قفل کیف‌پول با شکست مواجه شد</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>گذرواژهٔ کیف پول با موفقیت عوض شد.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>هشدار: کلید Caps Lock روشن است!</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>کیف پول</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;بررسی اجمالی</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>نمایش بررسی اجمالی کیف پول</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;ارسال</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;دریافت</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>مرور تاریخچهٔ تراکنش‌ها</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;خروج</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>خروج از برنامه</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;تنظیمات...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;نمایش/ عدم نمایش</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;رمزنگاری کیف پول...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;تغییر گذرواژه...</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>تغییر گذرواژهٔ مورد استفاده در رمزنگاری کیف پول</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>&amp;امضای پیام...</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>با&amp;زبینی پیام...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>پنجرهٔ ا&amp;شکال‌زدایی</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>باز کردن کنسول خطایابی و اشکال‌زدایی</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;فایل</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;تنظیمات</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;کمک‌رسانی</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>وضعیت به‌روز</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>به‌روز رسانی...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>تراکنش ارسال شد</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>تراکنش دریافت شد</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>کیف پول &lt;b&gt;رمزنگاری شده&lt;/b&gt; است و هم‌اکنون &lt;b&gt;قفل&lt;/b&gt; است</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>تعداد:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>بایت ها:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>مبلغ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>هزینه:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>هزینه ی پسین:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>پول خورد:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>مبلغ</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>تاریخ</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>تاییدیه ها</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>تأیید شده</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>کپی برچسب</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>کپی مقدار</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>کپی شناسهٔ تراکنش</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>کپی تعداد</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>بله</translation>
    </message>
    <message>
        <source>no</source>
        <translation>خیر</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(بدون برچسب)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(تغییر)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>ویرایش نشانی</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;برچسب</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;نشانی</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>نشانی گیرنده جدید</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>نشانی فرستنده جدید</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>ویرایش آدرس گیرنده</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>ویرایش آدرس قرستنده</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>نشانی وارد شده «%1» در حال حاضر در دفترچه وجود دارد.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>نمی‌توان کیف پول را رمزگشایی کرد.</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>گزینه‌ها</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;عمومی</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;شبکه</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>نگاشت درگاه شبکه با استفاده از پروتکل &amp;UPnP</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;درگاه:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>درگاه پراکسی (مثال 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;پنجره</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>تنها بعد از کوچک کردن پنجره، tray icon را نشان بده.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;کوچک کردن به سینی به‌جای نوار وظیفه</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>کوچک کردن &amp;در زمان بسته شدن</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;نمایش</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>زبان &amp;رابط کاربری:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;واحد نمایش مبالغ:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>انتخاب واحد پول مورد استفاده برای نمایش در پنجره‌ها و برای ارسال سکه.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;تأیید</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;لغو</translation>
    </message>
    <message>
        <source>default</source>
        <translation>پیش‌فرض</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>آدرس پراکسی داده شده صحیح نیست.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>فرم</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>در دسترس:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>تراز علی‌الحساب شما</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>نارسیده:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>جمع کل:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>تراز کل فعلی شما</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>ناموجود</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>نسخهٔ کلاینت</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;اطلاعات</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>زمان آغاز به کار</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>تعداد ارتباطات</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>زنجیرهٔ بلوک‌ها</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>تعداد فعلی بلوک‌ها</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>زمان آخرین بلوک</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>با&amp;ز کردن</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;کنسول</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation>جمع کل:</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>در:</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>فایلِ لاگِ اشکال زدایی</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>پاکسازی کنسول</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>دکمه‌های بالا و پایین برای پیمایش تاریخچه و &lt;b&gt;Ctrl-L&lt;/b&gt; برای پاک کردن صفحه.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>برای نمایش یک مرور کلی از دستورات ممکن، عبارت &lt;b&gt;help&lt;/b&gt; را بنویسید.</translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 بایت</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 کیلوبایت</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 مگابایت</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 گیگابایت</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>ارسال سکه</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>ورودی‌ها...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>به طور خودکار انتخاب شدند</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>بود جه نا کافی </translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>تعداد:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>بایت ها:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>مبلغ:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>هزینه:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>هزینه ی پسین:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>ارسال به چند دریافت‌کنندهٔ به‌طور همزمان</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>&amp;دریافت‌کنندهٔ جدید</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>پاکسازی &amp;همه</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>عملیات ارسال را تأیید کنید</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>&amp;ارسال</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>کپی تعداد</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>کپی مقدار</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(بدون برچسب)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>A&amp;مبلغ :</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>پرداخ&amp;ت به:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>پیام:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;برچسب:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>چسباندن نشانی از حافظهٔ سیستم</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>امضاها - امضا / تأیید یک پیام</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>ا&amp;مضای پیام</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>چسباندن نشانی از حافظهٔ سیستم</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>پیامی را که می‌خواهید امضا کنید در اینجا وارد کنید</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>امضای فعلی را به حافظهٔ سیستم کپی کن</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>ا&amp;مضای پیام</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>بازنشانی تمام فیلدهای پیام</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>پاک &amp;کردن همه</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;شناسایی پیام</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>بازنشانی تمام فیلدهای پیام</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>این پانل شامل توصیف کاملی از جزئیات تراکنش است</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Copy label</source>
        <translation>کپی برچسب</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>کپی مقدار</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>کپی شناسهٔ تراکنش</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>برچسب</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>آدرس</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>شنیدن هر گونه درگاه انجام پذیر نیست. ازlisten=0  برای اینکار استفاده کیند.</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>آدرس پراکسی اشتباه %s</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>بار گیری آدرس ها</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>شبکه مشخص شده غیرقابل شناسایی در onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>بود جه نا کافی </translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>بار گیری شاخص بلوک</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>بار گیری والت</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>آدرس پیش فرض قابل ذخیره نیست</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>اسکان مجدد</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>بار گیری انجام شده است</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>خطا</translation>
    </message>
</context>
</TS>